<div align="center">

  <img src="https://www.magniv.io/static/media/textlogo.e9b53078962edf01fb96e8f0eeab7880.svg" width="400px">

  **Core Library for One line data science infra.**

  <a href="https://www.loom.com/share/320a5e9750904f1da250ce1d4dfcd909"><img alt="Demo with Loom" src="https://img.shields.io/badge/Demo-loom-552586.svg?style=for-the-badge&labelColor=gray"></a>
______________________________________________________________________
<div align="left">

To learn more about magniv take a look at [our documentation](https://docs.magniv.io)

## Monitoring

Using the Magniv dashboard makes it easy to monitor running jobs. Each Magniv task is displayed with its previous run information, logs, code snippets, and other details. Users also have the ability to disable tasks and manually trigger new runs.

<div align="center">
  <img src="https://miro.medium.com/max/1160/1*F0JkAaq8e3fKiLj7gZCfzQ.gif" max-height="250px">
</div>

## Git CI/CD

Similar to tools like Heroku or Netlify, Magniv sets up a CI/CD pipeline from your GitHub repository. After connecting a Magniv workspace to a GitHub repo, every new commit will trigger a new build and update your tasks.

<div align="center">
  <img src="https://miro.medium.com/max/1240/1*4xigR6AHkwdB9Jfi779UDA.gif" max-height="250px">
</div>
